@@ -5,13 +5,7 @@ refine <- function (x, clustering, ...)
 
 refine.pco <- function (x, clustering, ax=1, ay=2, ...) 
 {
-    if (inherits(clustering,c('clustering','partana','partition'))) clustering <- clustering$clustering
-    if (is.numeric(clustering)) {
-        if (min(clustering)< 0 || (length(table(clustering)) != max(clustering))) {
-            cat('WARNING: renumbering clusters to consecutive integers\n')
-            clustering <- match(clustering,sort(unique(clustering)))
-        }
-    }
+    clustering <- as.integer(clustify(clustering))
 
     for (i in 1:max(clustering)) {
         plot(x, ax, ay)
@@ -34,11 +28,7 @@ refine.pco <- function (x, clustering, ax=1, ay=2, ...)
 
 refine.nmds <- function (x, clustering, ax=1, ay=2, ...) 
 {
-    if (inherits(clustering,c('clustering','partana','partition'))) clustering <- clustering$clustering
-    if (min(clustering)< 0 || (length(table(clustering)) != max(clustering))) {
-        cat('WARNING: renumbering clusters to consecutive integers\n')
-        clustering <- match(clustering,sort(unique(clustering)))
-    }
+    clustering <- as.integer(clustify(clustering))
 
     for (i in 1:max(clustering)) {
         plot(x, ax, ay)
@@ -61,14 +51,8 @@ refine.nmds <- function (x, clustering, ax=1, ay=2, ...)
 
 refine.default <- function (x,clustering, ...) 
 {
-    if (inherits(clustering,c('partana','clustering'))) {
-        clustering <- clustering$clustering
-    }
-    if (min(clustering)< 0 || (length(table(clustering)) != max(clustering))) {
-        cat('WARNING: renumbering clusters to consecutive integers\n')
-        clustering <- match(clustering,sort(unique(clustering)))
-    }
-
+    clustering <- as.integer(clustify(clustering))
+ 
     repeat {
         plots <- readline(' enter the plots    : ')
         if (plots == "") break
