@@ -1,12 +1,17 @@
+#silhouette <- function(x, dist, ...)
+#{
+#    UseMethod("silhouette")
+#}
+
 silhouette.partana <- function (x, dist, ...)
 {
     if (!inherits(x,'partana')) {
         stop("You must supply an object of class partana")
     }
-    if (class(dist) != 'dist') {
+    if (class(dist) != 'dist') { 
        stop("You need to specify a dist object as the second argument")
     }
-    tmp <- silhouette(as.numeric(factor(x$clustering)),dist,...)
+    tmp <- silhouette(as.numeric(clustify(x)),dist,...)
     row.names(tmp) <- attr(dist,'Labels')
     tmp
 }
@@ -16,19 +21,18 @@ silhouette.clustering <- function (x, dist, ...)
     if (!inherits(x,'clustering')) {
         stop("You must supply an object of class clustering as the first argument")
     }
-    if (min(x$clustering)< 0 || (length(table(x$clustering)) != max(x$clustering))) {
-        cat('WARNING: renumbering clusters to consecutive integers\n')
-        x$clustering <- match(x$clustering,sort(unique(x$clustering)))
-    }
 
     if (class(dist) != 'dist') {
         stop("You need to specify an object of class dist as the second argument")
     }
-    tmp <- silhouette(as.numeric(factor(x$clustering)),dist)
+    tmp <- silhouette(as.numeric(clustify(x)),dist)
     row.names(tmp) <- attr(dist,'Labels')
     tmp
 }
 
+
+
+
 silhouette.stride <- function(x,dist,...)
 {
     res <- rep(NA,ncol(x$clustering))
